Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8345)

Unified Diff: chrome/install_static/install_constants.h

Issue 2601443002: Remove multi-install from install_static. (Closed)
Patch Set: Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/install_static/install_constants.h
diff --git a/chrome/install_static/install_constants.h b/chrome/install_static/install_constants.h
index 1b79bceb11e6d970ff653d2340d56df3f74c17bf..9e2d313eda8e7fd07145d8ae569f457395e754df 100644
--- a/chrome/install_static/install_constants.h
+++ b/chrome/install_static/install_constants.h
@@ -58,8 +58,8 @@ struct InstallConstants {
// True if this mode supports system-level installs.
bool supports_system_level;
- // True if this mode supports multi-install.
- bool supports_multi_install;
+ // True if this mode supported multi-install.
huangs 2016/12/27 20:04:22 Add "(legacy)"?
grt (UTC plus 2) 2017/01/02 12:58:44 Done.
+ bool supported_multi_install;
};
} // namespace install_static

Powered by Google App Engine
This is Rietveld 408576698